changeset 9085:a199529ef171 libavcodec

small spelling/grammar fixes
author diego
date Mon, 02 Mar 2009 05:41:55 +0000
parents 0d39a5203bf0
children e1b522d24270
files imgresample.c mpegvideo.h
diffstat 2 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/imgresample.c	Mon Mar 02 05:20:00 2009 +0000
+++ b/imgresample.c	Mon Mar 02 05:41:55 2009 +0000
@@ -575,7 +575,7 @@
  * Otherwise, frees context and gets a new one.
  *
  * Be warned that srcFilter, dstFilter are not checked, they are
- * asumed to remain valid.
+ * assumed to remain valid.
  */
 struct SwsContext *sws_getCachedContext(struct SwsContext *ctx,
                         int srcW, int srcH, int srcFormat,
--- a/mpegvideo.h	Mon Mar 02 05:20:00 2009 +0000
+++ b/mpegvideo.h	Mon Mar 02 05:41:55 2009 +0000
@@ -600,7 +600,7 @@
     int broken_link;         ///< no_output_of_prior_pics_flag
     uint8_t *vbv_delay_ptr;  ///< pointer to vbv_delay in the bitstream
 
     /* MPEG2 specific - I wish I had not to support this mess. */
     int progressive_sequence;
     int mpeg_f_code[2][2];
     int picture_structure;
@@ -635,7 +635,7 @@
     int rtp_mode;
 
     uint8_t *ptr_lastgob;
-    int swap_uv;//vcr2 codec is mpeg2 varint with UV swaped
+    int swap_uv;             //vcr2 codec is an MPEG-2 variant with U and V swapped
     DCTELEM (*pblocks[12])[64];
 
     DCTELEM (*block)[64]; ///< points to one of the following blocks
@@ -600,7 +600,7 @@
     uint8_t *vbv_delay_ptr;  ///< pointer to vbv_delay in the bitstream
 
-    /* MPEG2 specific - I wish I had not to support this mess. */
+    /* MPEG-2-specific - I wished not to have to support this mess. */
     int progressive_sequence;
     int mpeg_f_code[2][2];